@@ -8,10 +8,12 @@ require(testthat)
 context("SDMXCrossSectionalData")
 
 test_that("CrossSectionalData 1.0",{
+  testthat::skip_on_travis()
+  testthat::skip_on_cran()
   file <- system.file("extdata", "SDMXCrossSectionalDataExample_1.0.xml", package = "rsdmx")
   xmlObj <- xmlParse(file)
-  
-  ds <- SDMXCrossSectionalData(xmlObj)
+  ns <- namespaces.SDMX(xmlObj)
+  ds <- SDMXCrossSectionalData(xmlObj, ns)
   expect_is(ds, "SDMXCrossSectionalData")
   
   df <- as.data.frame(ds)
