@@ -8,6 +8,8 @@ require(testthat)
 context("SDMXDataFlows")
 
 test_that("DataFlows - 2.1",{
+  testthat::skip_on_travis()
+  testthat::skip_on_cran()
   file <- system.file("extdata", "SDMXDataFlows_Example_2.1.xml", package = "rsdmx")
   xmlObj <- xmlParse(file)
   ns <- namespaces.SDMX(xmlObj)
@@ -28,4 +30,5 @@ test_that("DataFlows - 2.1",{
   expect_equal(flow.df[1, "version"], "1.0")
   expect_equal(flow.df[1, "urn"], "urn:sdmx:org.sdmx.infomodel.datastructure.Dataflow=MYORG:DS-001(1.0)")
   expect_equal(flow.df[1, "dsdRef"], "DSD_DS-001")
+  expect_equal(flow.df[1, "dsd"], NULL)
 })
