@@ -8,6 +8,8 @@ require(testthat)
 context("SDMXDataStructureDefinition")
 
 test_that("DataStructureDefinition (DSD) - 2.0",{
+  testthat::skip_on_travis()
+  testthat::skip_on_cran()
   file <- system.file("extdata", "SDMXDataStructureDefinition_Example_2.0.xml",
                       package = "rsdmx")
   xmlObj <- xmlParse(file)
@@ -20,12 +22,15 @@ test_that("DataStructureDefinition (DSD) - 2.0",{
 })
 
 test_that("DataStructureDefinition (DSD) - 2.1",{
+  testthat::skip_on_travis()
+  testthat::skip_on_cran()
   file <- system.file("extdata", "SDMXDataStructureDefinition_Example_2.1.xml",
                       package = "rsdmx")
   xmlObj <- xmlParse(file)  
   ns <- namespaces.SDMX(xmlObj)
   dsd <- SDMXDataStructureDefinition(xmlObj, ns)
   expect_is(dsd, "SDMXDataStructureDefinition")
+  expect_is(dsd@organisationSchemes, "SDMXOrganisationSchemes")
   expect_is(dsd@concepts, "SDMXConcepts")
   expect_is(dsd@codelists, "SDMXCodelists")
   expect_is(dsd@datastructures, "SDMXDataStructures")
